==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ImageColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ImageColumnDescription } from "./ImageColumnDescription";
/**
 * @hidden
 */
export let ImageColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageColumnDescriptionMetadata extends Base {
        static b(a) {
            if (ImageColumnDescriptionMetadata.a == null) {
                ImageColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageColumnDescriptionMetadata.c(ImageColumnDescriptionMetadata.a);
            }
            if (a.k(ImageColumnDescriptionMetadata.a)) {
                return;
            }
            a.aa(ImageColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
            a.item("ImageStretchOption@names", "Uniform;Fill;None");
            a.item("EditorType", "ExportedType:string:EditorType");
            a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
            a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
            a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("EditorTextField", "String");
            a.item("EditorValueField", "String");
        }
        static d(a) {
            ImageColumnDescriptionMetadata.b(a);
            a.ac("ImageColumn", () => new ImageColumnDescription());
            a.ab("ImageColumn", ImageColumnDescriptionMetadata.a);
        }
    }
    ImageColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(ImageColumnDescriptionMetadata, 'ImageColumnDescriptionMetadata');
    ImageColumnDescriptionMetadata.a = null;
    return ImageColumnDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ImageColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ImageColumnDescription } from "./ImageColumnDescription";
/**
 * @hidden
 */
export let ImageColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageColumnDescriptionMetadata extends Base {
        static b(a) {
            if (ImageColumnDescriptionMetadata.a == null) {
                ImageColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageColumnDescriptionMetadata.c(ImageColumnDescriptionMetadata.a);
            }
            if (a.k(ImageColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(ImageColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
            a.item("ImageStretchOption@names", "Uniform;Fill;None");
            a.item("EditorType", "ExportedType:string:EditorType");
            a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
            a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
            a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("EditorTextField", "String");
            a.item("EditorValueField", "String");
        }
        static d(a) {
            ImageColumnDescriptionMetadata.b(a);
            a.ae("ImageColumn", () => new ImageColumnDescription());
            a.ad("ImageColumn", ImageColumnDescriptionMetadata.a);
        }
    }
    ImageColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(ImageColumnDescriptionMetadata, 'ImageColumnDescriptionMetadata');
    ImageColumnDescriptionMetadata.a = null;
    return ImageColumnDescriptionMetadata;
})();
